<?php

/**
 * Add Banco Inter as a gateway method
 */
add_filter( 'woocommerce_payment_gateways', 'add_wc_banco_inter_gateway_class' );
function add_wc_banco_inter_gateway_class( $methods ) {
    $methods[] = 'WC_Banco_Inter';
    return $methods;
}

/**
* Operate Banco Inter at checkout
*/
add_action('woocommerce_checkout_process', 'process_wc_banco_inter_payment', 10);
function process_wc_banco_inter_payment(){

    if($_POST['payment_method'] != 'interboleto'){
        return;
    }

    /**Validate CNPJ OR CPF */
    if (class_exists( 'Extra_Checkout_Fields_For_Brazil' )){
        if(isset($_POST['billing_cpf']) AND strlen($_POST['billing_cpf']) != 0){
            $vat = sanitize_text_field( $_POST['billing_cpf']);
        }elseif(isset($_POST['billing_cnpj']) AND strlen($_POST['billing_cnpj']) != 0){
            $vat = sanitize_text_field( $_POST['billing_cnpj'] );
        }else{
            wc_add_notice( sprintf( '<strong>CNPJ ou CPF</strong> é obrigatório.' ), 'error' );
        }
    }else{
        ( isset($_POST['vat_inter'])
            AND strlen($_POST['vat_inter']) != 0
        ) ?
            $vat = sanitize_text_field( $_POST['vat_inter'] ) :
            wc_add_notice( sprintf( '<strong>CNPJ ou CPF</strong> é obrigatório.' ), 'error' );
    }


    if(empty($_POST['billing_address_1'])){
        wc_add_notice( sprintf( 'Campo <strong>Endereço</strong> é obrigatório.' ), 'error' );
    }


    if( class_exists( 'Extra_Checkout_Fields_For_Brazil' )){
        if( empty($_POST['billing_number']) ){
            wc_add_notice( sprintf( 'Campo <strong>Número</strong> é obrigatório.' ), 'error' );
        }
    }

    if ( empty( $_POST['billing_postcode'] ) ) {
        wc_add_notice( sprintf( 'Campo <strong>CEP</strong> é obrigatório.' ), 'error' );
    }else{
        /**API Cep */
        $bp = sanitize_text_field( $_POST['billing_postcode'] );
        $urlCep = "https://viacep.com.br/ws/".preg_replace("/[^0-9]/", "", $bp)."/json/";
        $argsCep = array(
            'timeout'       => 30,
            'method'        => 'GET'
        );
        $htt = _wp_http_get_object();
        $ends = $htt->get($urlCep, $argsCep); //print_r($ends);
        $end = json_decode($ends['body']);
        if(isset($end->erro)){
            wc_add_notice( sprintf( '<strong>CEP</strong> é inválido.' ), 'error' );
        }
    }

    
    /**Verificar a conexão com o Inter */
	$setings = WC_Banco_Inter::setingsApi();
    $CCInter = $setings["settings"][0]['CCInter'];

    /**Remover a porta a partir do dia 18, banco inter vai desativa-la */
    $url = "https://apis.bancointer.com.br/openbanking/v1/certificado/boletos";
    $datas = "?filtrarPor=TODOS&dataInicial=2020-08-07&dataFinal=2020-09-08&ordenarPor=NOSSONUMERO&page=0&size=1";
    $http = _wp_http_get_object();
	$argsCard = array(
		'timeout'       => 30,
		'method'        => 'GET',
		'httpversion'   => '1.1',
		//'body'          => json_encode( $registerCart ),
		'headers'       => [
			"x-inter-conta-corrente" => "$CCInter",
			"Content-Type" => "application/json"
		],
	);
	$tuBilletHttp =  wp_remote_get($url.$datas, $argsCard);
	$tuBillet =  json_decode($tuBilletHttp['body']);

    if($tuBilletHttp["response"]["code"] != '200'){
        bancointer_register_error($tuBilletHttp["response"]["message"].": ".$tuBilletHttp["response"]["code"]);
    }

    if($tuBillet != '' OR $tuBillet != false){
        // $tuData1->totalPages;
        // $tuData1 = json_decode($get);
    }else{
        wc_add_notice( sprintf( '<strong>Banco Inter:</strong> sistema indisponível, tente mais tarde ou escolha outro método de pagamento.' ), 'error' );
    }


}

/**
 * Update the order meta with field value
 */
add_action( 'woocommerce_checkout_update_order_meta', 'wc_banco_inter_payment_update_order_meta' );
function wc_banco_inter_payment_update_order_meta( $order_id ) {

    if($_POST['payment_method'] != 'interboleto'){
        return;
    }

    $order = wc_get_order( $order_id );

    /**API Cep */
    $bp = sanitize_text_field( $_POST['billing_postcode'] );
    $urlCep = "https://viacep.com.br/ws/".preg_replace("/[^0-9]/", "", $bp)."/json/";
    $argsCep = array(
        'timeout'       => 30,
        'method'        => 'GET'
    );
    $htt = _wp_http_get_object();
    $ends = $htt->get($urlCep, $argsCep);
    $end = json_decode($ends['body']);


    $vencimento = date('Y-m-d', (time()+250000));
    $data = date('Y-m-d');

    if (class_exists( 'Extra_Checkout_Fields_For_Brazil' )){
        if(isset($_POST['billing_cpf']) AND strlen($_POST['billing_cpf']) != 0){
            $vat = sanitize_text_field( $_POST['billing_cpf'] );
        }elseif(isset($_POST['billing_cnpj']) AND strlen($_POST['billing_cnpj']) != 0){
            $vat = sanitize_text_field( $_POST['billing_cnpj'] );
        }
    }else{
        ( isset($order->data['billing']['vat_inter'])
            AND strlen($order->data['billing']['vat_inter']) != 0
        ) ?
            $vat = sanitize_text_field( $_POST['vat_inter'] ) :
            false;
    }
    if(empty($vat) || $vat == ""){
        $vat = sanitize_text_field( $_POST['vat_inter'] );
    }

    /**Tratar o número do endereço com o Plugin Brazilian e sem ele */
    if(isset($_POST['billing_number'])){
        $number = sanitize_text_field( $_POST['billing_number'] );
    }elseif(isset($order->data['billing']['address_1'])){
        if(is_int(preg_replace("/[^0-9]/", "", $order->data['billing']['address_1']))){
            $number = preg_replace("/[^0-9]/", "", $order->data['billing']['address_1']);
        }else{
            $number = "0";
        }
    }else{
        $number = "0";
    }


    ( strlen(preg_replace("/[^0-9]/", "", $vat)) > 11 ) ? $tipo = "JURIDICA" : $tipo = "FISICA";

    $setings = wc_get_payment_gateway_by_order( $order_id );

    $billetData = [
        "pagador"=>[
           "key" => "",
           "cnpjCpf"=> preg_replace("/[^0-9]/", "", $vat),
           "nome"=>$order->get_billing_first_name().' '.$order->get_billing_last_name(),
           "email"=>"",
           "telefone"=>"",
           "cep"=>preg_replace("/[^0-9]/", "", $bp),
           "complemento"=>"",
           "bairro"=> $end->bairro,
           "numero"=>$number,
           "cidade"=>$end->localidade,
           "uf"=> $end->uf,
           "endereco"=>$end->logradouro,
           "ddd"=>"",
           "tipoPessoa"=>$tipo
        ],
        "dataEmissao"=> $data,
        "seuNumero"=>$order_id,
        "dataLimite"=>"TRINTA",
        "dataVencimento"=>$vencimento,
        "mensagem"=>[
           "linha1"=>"Compra de Nº ".$order_id,
           "linha2"=>"Caso o boleto não seja pago até a data",
           "linha3"=>"a compra será cancelada.",
           "linha4"=>"Fique atendo nos vencimentos e descontos.",
           "linha5"=>"Dúvidas, fale conosco."
        ],
        "desconto1"=>[
           "codigoDesconto"=>"NAOTEMDESCONTO",
           "taxa"=>0,
           "valor"=>0,
           "data"=>""
        ],
        "desconto2"=>[
           "codigoDesconto"=>"NAOTEMDESCONTO",
           "taxa"=>0,
           "valor"=>0,
           "data"=>""
        ],
        "desconto3"=>[
           "codigoDesconto"=>"NAOTEMDESCONTO",
           "taxa"=>0,
           "valor"=>0,
           "data"=>""
        ],
        "valorNominal"=>$order->get_total(),
        "valorAbatimento"=>0,
        "multa"=>[
           "codigoMulta"=>"NAOTEMMULTA",
           "valor"=>0,
           "taxa"=>0
        ],
        "mora"=>[
           "codigoMora"=>"ISENTO",
           "valor"=>0,
           "taxa"=>0
        ],
        "cnpjCPFBeneficiario"=>preg_replace("/[^0-9]/", "", $setings->settings['cnpjCPFBeneficiario']),
        "numDiasAgenda"=>"TRINTA"
    ];

    $datas = json_encode( $billetData, true );
    $CCInter = $setings->settings['CCInter'];

    $url = "https://apis.bancointer.com.br/openbanking/v1/certificado/boletos";
    $http = _wp_http_get_object();
	$argsCard = array(
		'timeout'       => 30,
		'method'        => 'POST',
		'httpversion'   => '1.1',
		'body'          => $datas,
		'headers'       => [
			"x-inter-conta-corrente" => "$CCInter",
			"Content-Type" => "application/json"
		],
	);
	
	try{
		$tuBilletHttp =  wp_remote_get($url, $argsCard);
	    $tuBillet =  json_decode($tuBilletHttp['body']);

        if($tuBilletHttp["response"]["code"] != '200'){
            bancointer_register_error($tuBilletHttp["response"]["message"].": ".$tuBilletHttp["response"]["code"]);
        }
	}catch(Exception $e){
		_e('Exceção capturada: ',  $e->getMessage(), "\n");
		wc_add_notice( sprintf( '<strong>Banco Inter: </strong>'.$e->getMessage() ), 'error' );
	}
	

    if($tuBillet != '' OR $tuBillet != false){
        $nossoNumero = $tuBillet->nossoNumero;
        $codigoBarras = $tuBillet->codigoBarras;

        update_post_meta( $order_id, 'boleto', $codigoBarras );
        update_post_meta( $order_id, 'nossonumero', $nossoNumero );
        update_post_meta( $order_id, 'transaction', $nossoNumero );
        
    }else{
        // print_r($tuData);
        // exit();
    }
    // var_dump($tuData);
    //exit();
}
