<?php
/**
 * Configurações do PIX
 * https://github.com/william-costa/wdev-qrcode-pix-estatico-php
 */

add_action('plugins_loaded', 'init_wc_banco_inter_gateway_pix_class');
function init_wc_banco_inter_gateway_pix_class(){

    class WC_Banco_Inter_PIX extends WC_Payment_Gateway {

        public $domain;


        /**
        * Constructor for the gateway.
        */
        public function __construct() {

            $this->domain = 'inter_boleto';

            $this->id                 = 'interpix';
            $this->icon               = apply_filters('woocommerce_custom_gateway_icon', '');
            $this->has_fields         = false;
            $this->method_title       = __( 'Banco Inter PIX', $this->domain );
            $this->method_description = sprintf (
                 __( 'Aviso: O Banco Inter ainda não Liberou a API de Integração para o PIX, dito isso, essa funcionalidade gera o PIX mas não consegue verificar se o cliente fez o pagamento.', $this->domain)
                ).
                sprintf (
                    __( '<br/>Precisa de ajuda para configurar? <a href="%s">Suporte</a>', $this->domain),
                    esc_url( 'https://www.diletec.com.br/contato/?utm_source=wordpress&utm_medium=plugin&utm_campaign=bancointer&utm_term=suporte&utm_content=config' )
                );

            // Load the settings.
            $this->init_form_fields();
            $this->init_settings();

            // Define user set variables
            $this->title                    = $this->get_option( 'title' );
            $this->description              = $this->get_option( 'description' );
            $this->instructions             = $this->get_option( 'instructions', $this->description );
            $this->order_status             = $this->get_option( 'order_status', 'on-hold' );
            $this->pixKey                   = $this->get_option( 'pix_key' );
            $this->pixMerchantName          = $this->get_option( 'pix_merchant_name' );
            $this->pixMerchantCity          = $this->get_option( 'pix_merchant_city' );


            // Actions
            add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
            add_action( 'woocommerce_thankyou_' . $this->id, array( $this, 'thankyou_page' ) );

            // Customer Emails woocommerce_email_before_order_table
            //add_action( 'woocommerce_email_after_order_table', array( $this, 'email_instructions' ), 10, 3 );
            // Customer Emails.
		    add_action( 'woocommerce_email_before_order_table', array( $this, 'email_instructions' ), 10, 3 );



        }

        /**
        * Initialise Gateway Settings Form Fields.
        */
        public function init_form_fields() {

            $this->form_fields = array(
                'enabled' => array(
                    'title'   => __( 'Enable/Disable', $this->domain ),
                    'type'    => 'checkbox',
                    'label'   => __( 'Enable inter', $this->domain ),
                    'default' => 'yes'
                ),
                'title' => array(
                    'title'       => __( 'Title', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'This controls the title which the user sees during checkout.', $this->domain ),
                    'default'     => __( 'Pix', $this->domain ),
                    'desc_tip'    => true,
                ),
                'order_status' => array(
                    'title'       => __( 'Order Status', $this->domain ),
                    'type'        => 'select',
                    'class'       => 'wc-enhanced-select',
                    'description' => __( 'Choose whether status you wish after checkout.', $this->domain ),
                    'default'     => 'wc-on-hold',
                    'desc_tip'    => true,
                    'options'     => wc_get_order_statuses()
                ),
                'description' => array(
                    'title'       => __( 'Description', $this->domain ),
                    'type'        => 'textarea',
                    'description' => __( 'Descrição do pagamento por PIX', $this->domain ),
                    'default'     => __('Descrição do pagamento por PIX', $this->domain),
                    'desc_tip'    => true,
                ),
                'instructions' => array(
                    'title'       => __( 'Instructions', $this->domain ),
                    'type'        => 'textarea',
                    'description' => __( 'Instruções de como realizar o pagamento por PIX', $this->domain ),
                    'default'     => 'Instruções de como realizar o pagamento por PIX',
                    'desc_tip'    => true,
                ),
                'pix_key' => array(
                    'title'       => __( 'Chave Pix', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'Chave do Pix a ser utilizada.', $this->domain ),
                    'default'     => '',
                    'desc_tip'    => true,
                ),
                'pix_merchant_name' => array(
                    'title'       => __( 'Nome do beneficiário', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'Nome do beneficiário', $this->domain ),
                    'default'     => '',
                    'desc_tip'    => true,
                ),
                'pix_merchant_city' => array(
                    'title'       => __( 'Cidade do beneficiário', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'Cidade, letras maiusculas e sem caracteres especiais.', $this->domain ),
                    'default'     => 'BELO HORIZONTE',
                    'desc_tip'    => true,
                ),

            );

        }

        /**
        * Output for the order received page.
        */
        public function thankyou_page() {
            if ( $this->instructions )
                return wpautop( wptexturize( $this->instructions ) );
        }

        /**
        * Add content to the WC emails.
        *
        * @access public
        * @param WC_Order $order
        * @param bool $sent_to_admin
        * @param bool $plain_text
        */
        // public function email_instructions( $order, $sent_to_admin, $plain_text = false ) {
        //     // if ( $this->instructions && ! $sent_to_admin && 'interboleto' === $order->payment_method && $order->has_status( 'pending' ) ) {
        //     //     _e(wpautop( wptexturize( $this->instructions ) ) . PHP_EOL);
        //     // }
        //     $method = get_post_meta( $order->get_id(), '_payment_method', true );
        //     if($method != 'interboleto' || $method != 'interpix'){
        //         return;
        //     }

        //     $boleto = get_post_meta( $order->get_id(), 'boleto', true );
        //     $nossonumero = get_post_meta( $order->get_id(), 'nossonumero', true );

        //     _e('<p><strong>'.__( 'Código de Barras' ).':</strong> ' . $boleto . '</p>');
        //     _e('<p><strong>'.__( 'Nosso número').':</strong> ' . $nossonumero . '</p>');
        //     _e('<p class="billetdownload"><a target="_blank" href="'.plugin_dir_url(__FILE__).'/tmp/boleto-'.$order->get_id().'.pdf">'.__( 'Baixar boleto').'</a></p>');

        // }

        /**
         * Get templates path.
         *
         * @return string
         */
        public static function get_templates_path() {
            return plugin_dir_path( __FILE__ ) . '../../templates/';
        }


        /**
         * Add content to the WC emails.
         *
         * @param  WC_Order $order         Order object.
         * @param  bool     $sent_to_admin Send to admin.
         * @param  bool     $plain_text    Plain text or HTML.
         * @return string
         */
        public static function email_instructions( $order, $sent_to_admin, $plain_text = false ) {
            $setings = wc_get_payment_gateway_by_order( $order->get_id() );
            $base    = get_option( 'woocommerce_email_base_color' );

            //if ( $setings->settings['instructions'] && ! $sent_to_admin && 'interpix' === $order->get_payment_method() && $order->has_status( 'on-hold' ) ) {
                _e( wp_kses_post( wpautop( 
                    wptexturize( $setings->settings['instructions'] )
                     ) . PHP_EOL 
                     /**Link do boleto */
                     .'<br><p class="billetdownload"><a style="
                     font-weight: 700 !important;
                     color: white !important;
                     font-size: larger !important;
                     padding: 15px !important;
                     background-color: '.$base.' !important;
                     margin: 10px 0px 10px 0px !important;
                     display: block !important;
                     text-decoration: none !important;
                     max-width: 50% !important;
                     text-align: center !important;" target="blank" href="'.$order->get_view_order_url().'">'._( 'Realizar o pagamento').'</a></p><br>'. PHP_EOL
                     ) );
            //}

            // print_r("Order: "); print_r($order); exit();
            // // WooCommerce 3.0 or later.
            // if ( method_exists( $order, 'get_meta' ) ) {
            //     if ( $sent_to_admin || 'on-hold' !== $order->get_status() || $this->id !== $order->get_payment_method() ) {
            //         return;
            //     }

            //     $data = $order->get_meta( '_payment_method' );
            // } else {
            //     if ( $sent_to_admin || 'on-hold' !== $order->status || $this->id !== $order->payment_method ) {
            //         return;
            //     }

            //     $data = get_post_meta( $order->id, '_payment_method', true );
            // }

            // $data = array('type' => '0','link' => 'https://#','method' => 'PIX', 'installments' => '2');
            // wc_get_template(
            //     'emails/default.php', array(
            //         'type'         => $data['type'],
            //         'link'         => $data['link'],
            //         'method'       => $data['method'],
            //         'installments' => $data['installments'],
            //     ), 'woocommerce/bancointer/', WC_Banco_Inter_PIX::get_templates_path()
            // );

            // if ( isset( $data['type'] ) ) {
            // 	if ( $plain_text ) {
            // 		wc_get_template(
            // 			'emails/plain-instructions.php', array(
            // 				'type'         => $data['type'],
            // 				'link'         => $data['link'],
            // 				'method'       => $data['method'],
            // 				'installments' => $data['installments'],
            // 			), 'woocommerce/pagseguro/', WC_PagSeguro::get_templates_path()
            // 		);
            // 	} else {
            // 		wc_get_template(
            // 			'emails/html-instructions.php', array(
            // 				'type'         => $data['type'],
            // 				'link'         => $data['link'],
            // 				'method'       => $data['method'],
            // 				'installments' => $data['installments'],
            // 			), 'woocommerce/pagseguro/', WC_PagSeguro::get_templates_path()
            // 		);
            // 	}
            // }

        }

        /**
         * Send email notification.
         *
         * @param string $subject Email subject.
         * @param string $title   Email title.
         * @param string $message Email message.
         */
        public static function send_email( $subject, $title, $message ) {
            $mailer = WC()->mailer();
            $order = $message;
            // $ords = wc_get_email_order_items(
            //     $order,
            //     array(
            //         'show_sku'      => false,
            //         'show_image'    => false,
            //         'image_size'    => array( 32, 32 ),
            //         'plain_text'    => 'left',
            //         'sent_to_admin' => false,
            //     )
            // );

            $orders = new WC_Order_Item_Product( $order );
            $product = $orders->get_product();
            //var_dump($product); exit();
            $message = '<div style="margin-bottom: 40px;">
            <table class="td" cellspacing="0" cellpadding="6" style="width: 100%; font-family: Helvetica, Roboto, Arial, sans-serif;" border="1">
                <thead>
                    <tr>
                        <th class="td" scope="col" style="text-align:left;">Produtos</th>
                        <th class="td" scope="col" style="text-align:left;">Quantidade</th>
                        <th class="td" scope="col" style="text-align:left;">Preço</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>'.
                    wc_get_email_order_items(
                        $order,
                        array(
                            'show_sku'      => false,
                            'show_image'    => false,
                            'image_size'    => array( 32, 32 ),
                            'plain_text'    => 'left',
                            'sent_to_admin' => false,
                        )
                    )
                .'</tr>
                </tbody>
                <tfoot>
                    Ok, aqui vem as instruções
                </tfoot>
            </table>
        </div>';


            $mailer->send( get_option( 'admin_email' ), $subject, $mailer->wrap_message( $title, $message ) );
        }

        /**
        * Process the payment and return the result.
        *
        * @param int $order_id
        * @return array
        */
        public function process_payment( $order_id ) {

            $order = wc_get_order( $order_id );
            $status = 'wc-' === substr( $this->order_status, 0, 3 ) ? substr( $this->order_status, 3 ) : $this->order_status;

            // Set order status
            $order->update_status( $status, __( 'Checkout with inter. ', $this->domain ) );

            // Reduce stock levels
            $order->reduce_order_stock();

            // Remove cart
            WC()->cart->empty_cart();

            // Return thankyou redirect
            return array(
                'result'    => 'success',
                'redirect'  => $this->get_return_url( $order )
            );
        }


        static public function setingsApi(){
            global $wpdb;
            $results = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}options
                WHERE option_name = 'woocommerce_interpix_settings'
            ");

            return [
                "settings" => [
                    unserialize( $results[0]->option_value )
                ]
            ];

        }


    }

}

/**
 * Add Banco Inter as a gateway method
 */
add_filter( 'woocommerce_payment_gateways', 'add_wc_banco_inter_gateway_pix_class' );
function add_wc_banco_inter_gateway_pix_class( $methods ) {
    $methods[] = 'WC_Banco_Inter_PIX';
    return $methods;
}

/**
 * Update the order meta with field value PIX
 */
add_action( 'woocommerce_checkout_update_order_meta', 'wc_banco_inter_pix_payment_update_order_meta' );
function wc_banco_inter_pix_payment_update_order_meta( $order_id ) {

    if($_POST['payment_method'] != 'interpix'){
        return;
    }

    $order = wc_get_order( $order_id );
    $setings = wc_get_payment_gateway_by_order( $order_id );
    $order_id;

    require __DIR__.'/Payload.php';

    //INSTANCIA PRINCIPAL DO PAYLOAD PIX
    $obPayload = (new Banco_Inter_Payload)->setPixKey($setings->settings['pix_key'])
                            ->setDescription($order_id)
                            /**Máximo 25 caracteres */
                            ->setMerchantName(mb_strimwidth($setings->settings['pix_merchant_name'], 0, 25, ))
                            /**Máximo 15 caracteres */
                            ->setMerchantCity(mb_strimwidth($setings->settings['pix_merchant_city'], 0, 15, ))
                            ->setAmount($order->get_total())
                            ->setTxid($order_id);


    //CÓDIGO DE PAGAMENTO PIX
    $payloadQrCode = $obPayload->getPayload();
    update_post_meta( $order_id, 'pix', $payloadQrCode );

    //print_r($payloadQrCode);
    //exit();
    //$wcInter = new WC_Banco_Inter_PIX;
    WC_Banco_Inter_PIX::email_instructions($order, 1, 0);
    //$wcInter::send_email("contato@diletec.com.br", "Compra no e-commerce", $order_id);

}

