<?php
/*
	* Plugin Name: Adicionar Banco Inter ao WooCommerce
	* Plugin URL: https://www.diletec.com.br
	* Description: Adiciona o Banco Inter como método de pagamento no seu WooCommerce
	* Version: 1.6.4
	* Author: Diletec
	* Author URI: https://www.diletec.com.br
    * Domain Path: /wc-banco-inter/
    * Requires at least: 4.4
    * Requires PHP: 7.0
    * WC requires at least: 3.0.0
    * WC tested up to: 5.5.1
    * Video: https://www.youtube.com/watch?v=CvPZweJQNEw
*/

/**
* https://stackoverflow.com/questions/17081483/custom-payment-method-in-woocommerce/37631908
* https://docs.woocommerce.com/document/payment-gateway-api/
* https://woocommerce.github.io/woocommerce-rest-api-docs/#order-properties
* crons https://developer.wordpress.org/plugins/cron/scheduling-wp-cron-events/
*/
define('BANCO_INTER_VERSION', '1.6.4');

/**
 * Custom Payment Gateway.
 *f
 * Provides a Custom Payment Gateway, mainly for testing purposes.
 */
add_action('plugins_loaded', 'init_wc_banco_inter_gateway_class');
function init_wc_banco_inter_gateway_class(){

    class WC_Banco_Inter extends WC_Payment_Gateway {

        public $domain;

        /**
        * Constructor for the gateway.
        */
        public function __construct() {

            $this->domain = 'inter_boleto';

            $this->id                 = 'interboleto';
            $this->icon               = apply_filters('woocommerce_custom_gateway_icon', '');
            $this->has_fields         = false;
            $this->method_title       = __( 'Banco Inter ', $this->domain );
            $this->method_description = sprintf (
                 __( 'Allows payments with Banco Inter gateway <a href="%s">Testar conexão com o banco.</a>', $this->domain),
                 esc_url( admin_url( 'admin.php?page=wc-settings&tab=checkout&section=interboleto&test=bancointerapi' ) )
                ).
                sprintf (
                    __( '<br/>Precisa de um técnico para configurar? <a href="%s">Contratar</a>', $this->domain),
                    esc_url( 'https://www.diletec.com.br/contato/?utm_source=wordpress&utm_medium=plugin&utm_campaign=bancointer&utm_term=suporte&utm_content=config' )
                );

            // Load the settings.
            $this->init_form_fields();
            $this->init_settings();
            $this->seting_alert_error();
            if(isset($_GET['test']) AND $_GET['test'] == 'bancointerapi'){$this->banco_inter_test_api_billet();}

            // Define user set variables
            $this->title                    = $this->get_option( 'title' );
            $this->description              = $this->get_option( 'description' );
            $this->instructions             = $this->get_option( 'instructions', $this->description );
            $this->order_status             = $this->get_option( 'order_status', 'on-hold' );
            $this->PathKey                  = $this->get_option( 'PathKey' );
            $this->PathCRT                  = $this->get_option( 'PathCRT' );
            $this->CCInter                  = $this->get_option( 'CCInter' );
            $this->cnpjCPFBeneficiario      = $this->get_option( 'cnpjCPFBeneficiario' );

            // Actions
            add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
            add_action( 'woocommerce_thankyou_' . $this->id, array( $this, 'thankyou_page' ) );

            // Customer Emails.
		    add_action( 'woocommerce_email_before_order_table', array( $this, 'email_instructions' ), 10, 3 );


            // add_action( 'rest_api_init', array( $this, 'inter_boleto_check_callback') );
        }

        /**
        * Initialise Gateway Settings Form Fields.
        */
        public function init_form_fields() {

            $this->form_fields = array(
                'enabled' => array(
                    'title'   => __( 'Enable/Disable', $this->domain ),
                    'type'    => 'checkbox',
                    'label'   => __( 'Enable inter', $this->domain ),
                    'default' => 'yes'
                ),
                'title' => array(
                    'title'       => __( 'Title', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'This controls the title which the user sees during checkout.', $this->domain ),
                    'default'     => __( 'inter', $this->domain ),
                    'desc_tip'    => true,
                ),
                'order_status' => array(
                    'title'       => __( 'Order Status', $this->domain ),
                    'type'        => 'select',
                    'class'       => 'wc-enhanced-select',
                    'description' => __( 'Choose whether status you wish after checkout.', $this->domain ),
                    'default'     => 'wc-on-hold', //'wc-pending',
                    'desc_tip'    => true,
                    'options'     => wc_get_order_statuses()
                ),
                'description' => array(
                    'title'       => __( 'Description', $this->domain ),
                    'type'        => 'textarea',
                    'description' => __( 'Payment method description that the customer will see on your checkout.', $this->domain ),
                    'default'     => __('Dados para o boleto', $this->domain),
                    'desc_tip'    => true,
                ),
                'instructions' => array(
                    'title'       => __( 'Instructions', $this->domain ),
                    'type'        => 'textarea',
                    'description' => __( 'Instructions that will be added to the thank you page and emails.', $this->domain ),
                    'default'     => '',
                    'desc_tip'    => true,
                ),
                'PathKey' => array(
                    'title'       => __( 'Path Key', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'Para integração com a API da inter deve ser utilizada a chave Key', $this->domain ),
                    'default'     => 'keys/meu.key',
                    'desc_tip'    => true,
                ),
                'PathCRT' => array(
                    'title'       => __( 'Path CRT', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'Para integração com a API da inter deve ser utilizada a chave CRT', $this->domain ),
                    'default'     => 'keys/meu.crt',
                    'desc_tip'    => true,
                ),
                'CCInter' => array(
                    'title'       => __( 'Conta Corrente', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'Conta corrente com o dígito (Apenas numeros)', $this->domain ),
                    'default'     => '',
                    'desc_tip'    => true,
                ),
                'cnpjCPFBeneficiario' => array(
                    'title'       => __( 'CPF/CNPJ do beneficiário', $this->domain ),
                    'type'        => 'text',
                    'description' => __( 'CPF ou CNPJ do proprietário da conta bancária', $this->domain ),
                    'default'     => '',
                    'desc_tip'    => true,
                ),
            );

        }

        /**
        * Output for the order received page.
        */
        public function thankyou_page() {
            if ( $this->instructions )
                return wpautop( wptexturize( $this->instructions ) );
        }


        /**
        * Add content to the WC emails.
        *
        * @access public
        * @param WC_Order $order
        * @param bool $sent_to_admin
        * @param bool $plain_text
        * https://woocommerce.wp-a2z.org/oik_api/wc_gateway_chequeemail_instructions/
        */
        public static function email_instructions( $order, $sent_to_admin, $plain_text = false ) {
            $setings = wc_get_payment_gateway_by_order( $order->get_id() );
            $base    = get_option( 'woocommerce_email_base_color' );

            if ( $setings->settings['instructions'] && ! $sent_to_admin && 'interboleto' == $order->get_payment_method() && $order->has_status( 'on-hold' ) ) {
                _e(wp_kses_post(
                        /**Instruções configuradas pelo Adm */
                        wpautop(
                            wptexturize( $setings->settings['instructions'] )
                        ) . PHP_EOL
                        /**Link do boleto */
                        .'<br><p class="billetdownload"><a style="
                        font-weight: 700 !important;
                        color: white !important;
                        font-size: larger !important;
                        padding: 15px !important;
                        background-color: '.$base.' !important;
                        margin: 10px 0px 10px 0px !important;
                        display: block !important;
                        text-decoration: none !important;
                        max-width: 50% !important;
                        text-align: center !important;" target="_blank" href="'.plugin_dir_url(__FILE__).'/tmp/boleto-'.$order->get_id().'.pdf">'.__( 'Baixar boleto').'</a></p><br>'. PHP_EOL
                    ));
            }

        }



        public function payment_fields(){

            if ( $description = $this->get_description() ) {
                _e(wpautop( wptexturize( $description ) ));
            }
            if (!class_exists( 'Extra_Checkout_Fields_For_Brazil' )){
            ?>
            <div id="custom_input">
                <div class="form-group">
                    <label>
                        CPF/CNPJ
                        <abbr class="required" title="obrigatório">*</abbr>
                    </label><br/>
                    <input type="text" name="vat_inter" required="required">
                </div>
            </div>
            <?php
            }
        }

        /**
        * Process the payment and return the result.
        *
        * @param int $order_id
        * @return array
        */
        public function process_payment( $order_id ) {

            $order = wc_get_order( $order_id );

            $status = 'wc-' === substr( $this->order_status, 0, 3 ) ? substr( $this->order_status, 3 ) : $this->order_status;

            // Set order status
            $order->update_status( $status, __( 'Checkout with inter. ', $this->domain ) );

            // Reduce stock levels
            $order->reduce_order_stock();

            // Remove cart
            WC()->cart->empty_cart();

            // Return thankyou redirect
            return array(
                'result'    => 'success',
                'redirect'  => $this->get_return_url( $order )
            );
        }

        public function seting_alert_error(){

            if(isset($_GET['page']) AND isset($_GET['tab']) AND isset($_GET['section'])){
                if(!file_exists(getcwd() .'/../'.$this->get_option("PathCRT"))){
                    bancointer_acf_notice_dainamic("Não encontramos o arquivo ". $this->get_option("PathCRT"));
                }
                if(!file_exists(getcwd() .'/../'.$this->get_option("PathKey"))){
                    bancointer_acf_notice_dainamic("Não encontramos o arquivo ". $this->get_option("PathKey"));
                }
            }

        }

        public function banco_inter_test_api_billet(){
            $setings = WC_Banco_Inter::setingsApi();
            $CCInter = $setings["settings"][0]['CCInter'];

            $url1 = "https://apis.bancointer.com.br/openbanking/v1/certificado/boletos";
            $datas = "?filtrarPor=TODOS&dataInicial=2021-01-01&dataFinal=2021-04-10&ordenarPor=NOSSONUMERO&page=0&size=10";

            $http = _wp_http_get_object();
            $argsCard = array(
                'timeout'       => 30,
                'method'        => 'GET',
                'httpversion'   => '1.1',
                //'body'          => json_encode( $registerCart ),
                'headers'       => [
                    "x-inter-conta-corrente" => "$CCInter",
                    "Content-Type" => "application/json"
                ],
            );
            $tuBilletHttp =  wp_remote_get($url1.$datas, $argsCard);
            $tuBillet =  json_decode( sanitize_text_field( $tuBilletHttp['body'] ) );

            if($tuBilletHttp["response"]["code"] != '200'){
                bancointer_register_error($tuBilletHttp["response"]["message"].": ".$tuBilletHttp["response"]["code"]);
            }

            if(isset($tuBillet->totalPages)){
                $menssage = 'resultou em Sucesso!';
                $typeError = 'success';
            }else{
                $menssage = 'teve erro de comunicação! Para suporte envie um e-mail para contato@diletec.com.br';
                $typeError = 'error';
            }
            _e(sprintf( __( '<div class="notice notice-'.$typeError.' is-dismissible interboleto-acf-notice-dainamic"><p>A conexão com o Banco Inter '.$menssage.'</p></div>', 'bancointer') ));
            false;
        }

        public static function setingsApi(){
            global $wpdb;
            $results = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}options
                WHERE option_name = 'woocommerce_interboleto_settings'
            ");

            return [
                "settings" => [
                    unserialize( $results[0]->option_value )
                ]
            ];

        }


    }

    /**
    * Configurar os sertificados
    */
    add_action('http_api_curl', function( $handle ){
        $setings = WC_Banco_Inter::setingsApi();
        $CCInter = $setings["settings"][0]['CCInter'];
        (file_exists(getcwd() .'/../'.$setings["settings"][0]['PathCRT'])) ? $codificado = getcwd() .'/../'.$setings["settings"][0]['PathCRT'] : $codificado = $setings["settings"][0]['PathCRT'];
        (file_exists(getcwd() .'/../'.$setings["settings"][0]['PathKey'])) ? $decodificado = getcwd() .'/../'.$setings["settings"][0]['PathKey'] : $decodificado = $setings["settings"][0]['PathKey'];

        curl_setopt($handle, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($handle, CURLOPT_SSL_VERIFYHOST, false);

        curl_setopt($handle, CURLOPT_SSLCERT, $codificado);
        curl_setopt($handle, CURLOPT_SSLKEY, $decodificado);
        curl_setopt($handle, CURLOPT_CAINFO, $codificado);
    }, 10);

}



/**
 * System
 */
include_once plugin_dir_path(__FILE__).'includes/system.php';

/**
 * Register
 */
include_once plugin_dir_path(__FILE__).'includes/register.php';

/**
 * Register erros in notice
 */
include_once plugin_dir_path(__FILE__).'includes/registerError.php';

/**
 * Register erros in notice
 */
include_once plugin_dir_path(__FILE__).'includes/billetGeneratorPdf.php';

/**
 * Register Gateway Banco Inter Billet
 */
include_once plugin_dir_path(__FILE__).'includes/gatewayBillet.php';

/**
 * Display field value on the order edit page
 */
include_once plugin_dir_path(__FILE__).'includes/adminDisplay.php';

/**
 * Operate BancoInter on the order screen
 */
include_once plugin_dir_path(__FILE__).'includes/customerDisplay.php';

/**
 * Cron
 */
include_once plugin_dir_path(__FILE__).'includes/cronBilet.php';

/**
 * Status
 */
include_once plugin_dir_path(__FILE__).'includes/statusBillet.php';

/**
 * PIX
 */
include_once plugin_dir_path(__FILE__).'includes/pix/gatewayPix.php';

/**
 * System
 */
include_once plugin_dir_path(__FILE__).'includes/system.php';

/**
 * Menu
 */
include_once plugin_dir_path(__FILE__).'includes/menu.php';


/**
 * Register settings link
 */
function wc_banco_inter_show_plugin_settings_link($links, $file){
    $new_actions = array();
    if ( basename( plugin_dir_path( __FILE__ ) ) . '/index.php' === $file ) {
        $new_actions['bancointer_settings'] = sprintf( __( '<a href="%s">Settings</a>', 'comment-limiter' ), esc_url( admin_url( 'admin.php?page=wc-settings&tab=checkout&section=interboleto' ) ) );
    }

    return array_merge( $new_actions, $links );

}
add_filter('plugin_action_links', 'wc_banco_inter_show_plugin_settings_link', 10, 2 );

function bancointer_register() {
    banco_inter_license();
}
register_activation_hook( __FILE__, 'bancointer_register' );
if(!file_exists(__DIR__.'/protected/license/license.txt')){
    add_action('plugins_loaded', 'bancointer_register' );
}

/**
 * Register style
 */
function bancointer_btn_bille() {
    wp_enqueue_style( 'bancointer-btn-billet', plugin_dir_url(__FILE__).'/assets/css/bancointer-btn-billet.css' );
}
add_action( 'wp_enqueue_scripts', 'bancointer_btn_bille' );

/**
 * wc_add_notice( __('Payment error:', 'woothemes') . $error_message, 'error' ); return;
 * https://docs.woocommerce.com/document/payment-gateway-api/
 */

/**
 * Callback
 * https://wordpress.diletec.com.br/wp-json/inter/v3/orders/9
*/
function inter_boleto_check_callback(){
    register_rest_route( 'inter/v3', '/orders/?[A-Za-z0-9]',
        array(
            'methods' => 'GET',
            'callback' => 'inter_boleto_callback',
            'permission_callback' => '__return_true',
        )
    );
}
add_action( 'rest_api_init', 'inter_boleto_check_callback');

function inter_boleto_callback($data){
    print_r($data);
    //print_r($data->route());
    //$data->getProperty(true);
    //$data->getValue($data->route);
    //_e($data['route']);
    //_e( $data->route );
}



